/* u8_to_dec_rj
   u8_to_dec_lj
   u16_to_dec_rj
   u16_to_dec_lj
   u32_to_dec_rj
   u32_to_dec_lj

   Unsigned integer to decimal string conversion routines.
   Enter with an unsigned char, short, or long integer.
   Returns a pointer to a 3, 5, or 10-digit string, either
   left or right-justified in a fixed-length field.  Buffer
   is terminated with a null character.

   Example:
   Assume "result" is an 8-bit unsigned integer value,
   SCI_putStr is a function that prints a string buffer, and
   &ESCI_A is the address of the serial I/O device.

     SCI_putStr( &ESCI_A, u8_to_dec_lj( result ));

   will print a left-justified 3-character string to the I/O
   containing an ASCII representation of the value in "result"
   plus a null char to terminate the string.

   -----

   Copyright (c) Freescale Semiconductor, Inc., 2004

   This file is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this file; if not, write to:

   Free Software Foundation, Inc.
   59 Temple Place, Suite 330
   Boston, MA  02111-1307  USA

*/

/*
$Id: $
*/

#define U8_DIGITS   3
#define U16_DIGITS  5
#define U32_DIGITS 10

char * u8_to_dec_rj  (unsigned char  number);
char * u8_to_dec_lj  (unsigned char  number);
char * u16_to_dec_rj (unsigned short number);
char * u16_to_dec_lj (unsigned short number);
char * u32_to_dec_rj (unsigned int   number);
char * u32_to_dec_lj (unsigned int   number);

/* ------------------------------------------------------------ */
char *
u32_to_dec_rj (unsigned int number)
{
  static char buf[U32_DIGITS + 1];
  short index = U32_DIGITS - 1;
  unsigned int u32_val = (unsigned int) number;

  buf[U32_DIGITS] = (char) 0;

  /* fill the buffer with ASCII decimal digits */
  do {
    buf[index--] = (u32_val % 10) + '0';
    u32_val /= 10;
  } while (u32_val);

  /* pad the buffer with spaces */
  while (index >= 0)
    buf[index--] = ' ';

  /* return a pointer to the buffer */
  return buf;
}

/* ------------------------------------------------------------ */
char *
u32_to_dec_lj (unsigned int number)
{
  static char rbuf[U32_DIGITS + 1];
  static char buf[U32_DIGITS];
  unsigned int u32_val = (unsigned int) number;
  short i, j;

  /* fill the buffer with ASCII decimal digits */
  i = 0;
  do {
    buf[i++] = (u32_val % 10) + '0';
    u32_val /= 10;
  } while (u32_val);

  rbuf[U32_DIGITS] = (char) 0;

  /* reverse the order of the digits */
  j = 0;
  while (i > 0)
    rbuf[j++] = buf[--i];

  /* pad the buffer with spaces */
  while (j < U32_DIGITS)
    rbuf[j++] = ' ';

  /* return a pointer to the reversed buffer */
  return rbuf;
}

/* ------------------------------------------------------------ */
char *
u16_to_dec_rj (unsigned short number)
{
  static char buf[U16_DIGITS + 1];
  short index = U16_DIGITS - 1;
  unsigned short u16_val = (unsigned short) number;

  buf[U16_DIGITS] = (char) 0;

  /* fill the buffer with ASCII decimal digits */
  do {
    buf[index--] = (u16_val % 10) + '0';
    u16_val /= 10;
  } while (u16_val);

  /* pad the buffer with spaces */
  while (index >= 0)
    buf[index--] = ' ';

  /* return a pointer to the buffer */
  return buf;
}

/* ------------------------------------------------------------ */
char *
u16_to_dec_lj (unsigned short number)
{
  static char rbuf[U16_DIGITS + 1];
  static char buf[U16_DIGITS];
  unsigned short u16_val = (unsigned short) number;
  short i, j;

  /* fill the buffer with ASCII decimal digits */
  i = 0;
  do {
    buf[i++] = (u16_val % 10) + '0';
    u16_val /= 10;
  } while (u16_val);

  rbuf[U16_DIGITS] = (char) 0;

  /* reverse the order of the digits */
  j = 0;
  while (i > 0)
    rbuf[j++] = buf[--i];

  while (j < U16_DIGITS)
    rbuf[j++] = ' ';

  /* return a pointer to the reversed buffer */
  return rbuf;
}

/* ------------------------------------------------------------ */
char *
u8_to_dec_rj (unsigned char number)
{
  static char buf[U8_DIGITS + 1];
  short index = U8_DIGITS - 1;
  unsigned char u8_val = (unsigned char) number;

  buf[U8_DIGITS] = (char) 0;

  /* fill the buffer with ASCII decimal digits */
  do {
    buf[index--] = (u8_val % 10) + '0';
    u8_val /= 10;
  } while (u8_val);

  /* pad the buffer with spaces */
  while (index >= 0)
    buf[index--] = ' ';

  /* return a pointer to the buffer */
  return buf;
}

/* ------------------------------------------------------------ */
char *
u8_to_dec_lj (unsigned char number)
{
  static char rbuf[U8_DIGITS + 1];
  static char buf[U8_DIGITS];
  unsigned char u8_val = (unsigned char) number;
  short i, j;

  /* fill the buffer with ASCII decimal digits */
  i = 0;
  do {
    buf[i++] = (u8_val % 10) + '0';
    u8_val /= 10;
  } while (u8_val);

  rbuf[U8_DIGITS] = (char) 0;

  /* reverse the order of the digits */
  j = 0;
  while (i > 0)
    rbuf[j++] = buf[--i];

  while (j < U8_DIGITS)
    rbuf[j++] = ' ';

  /* return a pointer to the reversed buffer */
  return rbuf;
}
